@@ -34,7 +34,7 @@ LOCAL char *yaml_names[] = {
 #endif
 
 
-#define YAML_NODE_SEQUENCE_VALUE (char *)1
+#define YAML_NODE_SEQUENCE_VALUE GINT_TO_POINTER(1)
 typedef struct {
     char      *key;
     char      *value;
@@ -123,7 +123,7 @@ LOCAL void arkime_rules_parser_free_node(YamlNode_t *node)
 {
     if (node->key)
         g_free(node->key);
-    if (node->value > YAML_NODE_SEQUENCE_VALUE)
+    if (node->value != YAML_NODE_SEQUENCE_VALUE)
         g_free(node->value);
     if (node->values)
         g_ptr_array_free(node->values, TRUE);
@@ -292,7 +292,7 @@ LOCAL void arkime_rules_load_add_field(ArkimeRule_t *rule, int pos, char *key)
     float            f;
     uint32_t         fint;
     GPtrArray       *rules;
-    patricia_node_t *node;
+    patricia_node_t *node = 0;
 
     config.fields[pos]->ruleEnabled = 1;
 
@@ -378,6 +378,8 @@ LOCAL void arkime_rules_load_add_field(ArkimeRule_t *rule, int pos, char *key)
             if (rule->setRule)
                 node = make_and_lookup(loading.fieldsTree6[pos], key);
         }
+        if (!node)
+            break;
         if (rule->setRule) {
             if (node->data) {
                 rules = node->data;
